@@ -35,6 +35,8 @@ char *help_main_menu[] = {
 		" ^0^...^9^ set a mark in a window so that you can",
 		"       easily see what has changed since the last",
 		"       time you looked",
+		" ^o^     wipe (clear) a window",
+		" ^O^     wipe all windows",
 		" ^r^     redraw screen",
 		" ^l^     list keybindings",
 		" ^i^     info",
@@ -504,7 +506,7 @@ char *help_set_windowsizes[] = {
 		"Here you can set the sizes of windows. The width",
 		"can only set for *all* windows, the height can be",
 		"set for each individual window.",
-		" ^w^     set the width for all windows",
+		" ^m^     manage columns: add a column, set width",
 		" ^h^     set the height for a window",
 		"Press ^ctrl+g^ to abort.",
 		NULL
@@ -603,13 +605,42 @@ char *help_scrollback_edit_search_string[] = {
 	};
 
 char *help_pause_a_window[] = {
-		/*2345678901234567890123456789012345678901234567890 */
 		"Select the window to (un-)pause. When a window is",
 		"paused, it won't be updated until the window is",
 		"un-paused. NOTHING will be discarded.",
 		NULL
 	};
 
+char *help_ask_colors_select_color[] = {
+		"Select the color or attribute to use.",
+		NULL
+	};
+
+char *help_set_vertical_split_n_win[] = {
+		/*2345678901234567890123456789012345678901234567890 */
+		"Enter the number of columns to split the terminal",
+		"in. If you press 'j' in the menu, you can also",
+		"select the number of windows per column.",
+		NULL
+	};
+
+char *help_manage_cols[] = {
+		/*2345678901234567890123456789012345678901234567890 */
+		/* FIXME: */
+		"fixme",
+		NULL
+	};
+
+char *help_wipe_window[] = {
+		/*2345678901234567890123456789012345678901234567890 */
+		"Press the number of the window to wipe. The number",
+		"can be found in the status-line of the windows.",
+		"Press 'r' to redraw the windows so that you can",
+		"see their contents again.",
+		NULL
+	};
+
+
 help_t	help[] =
 {
 	{ HELP_MAIN_MENU,			help_main_menu },
@@ -667,7 +698,10 @@ help_t	help[] =
 	{ HELP_SCROLLBACK_DELETE_MARK_SELECT_WINDOW,	help_scrollback_delete_mark_select_window },
 #endif
 	{ HELP_PAUSE_A_WINDOW,			help_pause_a_window },
-
+	{ HELP_ASK_COLORS_SELECT_COLOR,		help_ask_colors_select_color },
+	{ HELP_SET_VERTICAL_SPLIT_N_WIN, 	help_set_vertical_split_n_win },
+	{ HELP_MANAGE_COLS,			help_manage_cols },
+	{ HELP_WIPE_WINDOW,			help_wipe_window },
 	{ -1, NULL }
 };
 
