@@ -26,13 +26,13 @@
 #ifdef __OpenBSD__
 #include <util.h>
 #endif
-#if defined(linux) || defined(__CYGWIN__)
+#if defined(linux) || defined(__CYGWIN__) || defined(__GNU__)
 #include <pty.h>
 #endif
 #ifdef __FreeBSD__
 #include <libutil.h>
 #endif
-#ifdef sun
+#if defined(sun) || defined(__sun)
 #include <sys/stropts.h>
 #include <stdlib.h>
 #endif
@@ -74,7 +74,7 @@
 
 int get_pty_and_fork(int *fd_master, int *fd_slave)
 {
-#if defined(__FreeBSD__) || defined(linux) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__) || defined(__CYGWIN__)
+#if defined(__FreeBSD__) || defined(linux) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__) || defined(__CYGWIN__) || defined(__GNU__)
 
 	if (openpty(fd_master, fd_slave, NULL, NULL, NULL) == -1)
 	{
@@ -84,14 +84,14 @@ int get_pty_and_fork(int *fd_master, int *fd_slave)
 
 	return fork();
 
-#elif defined(sun) || defined(AIX) || defined(hpux) || defined(__hpux) || defined(OSF1)
+#elif defined(sun) || defined(__sun) || defined(AIX) || defined(hpux) || defined(__hpux) || defined(OSF1)
 
-        /*
-         * This code is used e.g. on Solaris 2.x.  (Note that Solaris 2.3
-         * also has bsd-style ptys, but they simply do not work.)
-         */
-        int ptm;
-        char *pts;
+	/*
+	 * This code is used e.g. on Solaris 2.x.  (Note that Solaris 2.3
+	 * also has bsd-style ptys, but they simply do not work.)
+	 */
+	int ptm;
+	char *pts;
 	pid_t pid;
 #if defined(AIX)
 	char *multiplexer = "/dev/ptc";
@@ -99,35 +99,35 @@ int get_pty_and_fork(int *fd_master, int *fd_slave)
 	char *multiplexer = "/dev/ptmx";
 #endif
 
-        ptm = myopen(multiplexer, O_RDWR | O_NOCTTY);
-        if (ptm < 0) {
-                error_exit("error opening %s", multiplexer);
-                return -1;
-        }
-        *fd_master = ptm;
+	ptm = myopen(multiplexer, O_RDWR | O_NOCTTY);
+	if (ptm < 0) {
+		error_exit("error opening %s", multiplexer);
+		return -1;
+	}
+	*fd_master = ptm;
 
 	pid = fork();
 	if (pid == 0)
 	{
-	        if (grantpt(ptm) < 0) error_exit("grantpt failed");
-	        if (unlockpt(ptm) < 0) error_exit("unlockpt failed");
+		if (grantpt(ptm) < 0) error_exit("grantpt failed");
+		if (unlockpt(ptm) < 0) error_exit("unlockpt failed");
 		setsid(); /* lose old controlling terminal (FvH) */
-	        pts = ptsname(ptm);
-	        if (pts == NULL) error_exit("Slave pty side name could not be obtained.");
+		pts = ptsname(ptm);
+		if (pts == NULL) error_exit("Slave pty side name could not be obtained.");
 
-	        /* Open the slave side. */
-	        *fd_slave = myopen(pts, O_RDWR | O_NOCTTY);
-	        if (*fd_slave < 0) error_exit("problem opening slave-side of pseudo tty (%s)", pts);
+		/* Open the slave side. */
+		*fd_slave = myopen(pts, O_RDWR | O_NOCTTY);
+		if (*fd_slave < 0) error_exit("problem opening slave-side of pseudo tty (%s)", pts);
 
 #ifndef AIX
-	        /* Push the appropriate streams modules, as described in Solaris pts(7). */
-	        if (ioctl(*fd_slave, I_PUSH, "ptem") < 0) error_exit("ioctl I_PUSH ptem failed");
-	        if (ioctl(*fd_slave, I_PUSH, "ldterm") < 0) error_exit("ioctl I_PUSH ldterm failed");
-	        (void)ioctl(*fd_slave, I_PUSH, "ttcompat"); /* not on HP-UX? */
+		/* Push the appropriate streams modules, as described in Solaris pts(7). */
+		if (ioctl(*fd_slave, I_PUSH, "ptem") < 0) error_exit("ioctl I_PUSH ptem failed");
+		if (ioctl(*fd_slave, I_PUSH, "ldterm") < 0) error_exit("ioctl I_PUSH ldterm failed");
+		(void)ioctl(*fd_slave, I_PUSH, "ttcompat"); /* not on HP-UX? */
 #endif
 	}
 
-        return pid;
+	return pid;
 
 #elif defined(IRIX) || defined(IRIX64)
 
@@ -141,16 +141,16 @@ int get_pty_and_fork(int *fd_master, int *fd_slave)
 
 #else
 
-	#error I'm sorry, but I don't know what kind of system this is.
-	#error Because of that I do not know how to do openpty() on your
-	#error system. Please contact me at folkert@vanheusden.com and
-	#error tell me what kind of system you have and please give me
-	#error the output of
-	#error man openpty
-	#error strings `which gcc`
-	#error strings `which cc`
-	#error ls -lR /usr/include
-	#error Thank you in advance and sorry for all the hassle!
+#error I'm sorry, but I don't know what kind of system this is.
+#error Because of that I do not know how to do openpty() on your
+#error system. Please contact me at folkert@vanheusden.com and
+#error tell me what kind of system you have and please give me
+#error the output of
+#error man openpty
+#error strings `which gcc`
+#error strings `which cc`
+#error ls -lR /usr/include
+#error Thank you in advance and sorry for all the hassle!
 
 #endif
 }
