@@ -7,7 +7,7 @@
 #define TERM_ANSI	1
 
 void wrong_key(void);
-char ask_yes_no(int what_help, NEWWIN *popup);
+int ask_yes_no(int what_help, NEWWIN *popup);
 void color_on(NEWWIN *win, int index);
 void color_off(NEWWIN *win, int index);
 void inverse_on(NEWWIN *win);
@@ -23,3 +23,4 @@ NEWWIN * mynewwin(int nlines, int ncols, int begin_y, int begin_x);
 void escape_print(NEWWIN *win, int y, int x, char *str);
 void win_header(NEWWIN *win, char *str);
 void gui_window_header(char *string);
+void error_popup(char *title, int help, char *message, ...);
